Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExecConf ¶
type ExecConf struct {
Job string `json:"job"`
Command string `json:"command"`
Args []string `json:"args"`
Env []string `json:"env"`
Dir string `json:"dir"`
}
ExecConf is a struct to define configuration of execution configs
func ReadExecConfDir ¶
func ReadExecConfFile ¶
ReadExecConfFile Reads configuration json file and converts to ExecConf
Click to show internal directories.
Click to hide internal directories.